@@ -9,7 +9,7 @@ use Exporter 'import';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-30'; # DATE
 our $DIST = 'List-Util-groupby'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(
                        groupby
@@ -79,7 +79,7 @@ List::Util::groupby - Group items of a list into several (possibly multilevel) b
 
 =head1 VERSION
 
-This document describes version 0.002 of List::Util::groupby (from Perl distribution List-Util-groupby), released on 2023-09-30.
+This document describes version 0.003 of List::Util::groupby (from Perl distribution List-Util-groupby), released on 2023-09-30.
 
 =head1 SYNOPSIS
 
@@ -93,12 +93,18 @@ This document describes version 0.002 of List::Util::groupby (from Perl distribu
    {name=>"andi",date=>"2023-09-30",result=>10.3},
    {name=>"budi",date=>"2023-09-29",result=>11.1},
    {name=>"budi",date=>"2023-09-30",result=>10.5},
- my @buckets = hgroupby { $_->{name} } @recs;
+ my %buckets = hgroupby { $_->{name} } @recs;
  # => (
  #   andi => [ {name=>"andi",date=>"2023-09-29",result=>9.8} , {name=>"andi",date=>"2023-09-30",result=>10.3} ],
  #   budi => [ {name=>"budi",date=>"2023-09-29",result=>11.1}, {name=>"budi",date=>"2023-09-30",result=>10.5} ],
  # )
 
+ my %buckets = hgroupby { [$_%2, $_%3] } 1..10;
+ #{
+ #  "0" => { "0" => [6], "1" => [4, 10], "2" => [2, 8] },
+ #  "1" => { "0" => [3, 9], "1" => [1, 7], "2" => [5] },
+ #}
+
 =head1 DESCRIPTION
 
 This module provides L</groupby>.
@@ -121,12 +127,16 @@ Code is expected to return an integer index to indicate which bucket the item
 should be grouped into. Code can also return an arrayref of integer indices for
 multilevel buckets.
 
-Return a hash of arrayrefs.
+Return a (possibly multilevel) array of arrayrefs.
 
 =head2 hgroupby
 
+Usage:
+
+ %buckets = hgroupby CODE ARRAY
+
 Just like L</groupby>, except code is expected to return keys (of arrayref of
-keys) and the function will return a list of hashrefs.
+keys) and the function will return a (possibly multilevel) hash of arrayrefs.
 
 =head1 HOMEPAGE
 
